<?php

namespace Icosettings\IcoSettings\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Icosettings\IcoSettings\Http\Requests\IcoSettingUserRequest;
use Icosettings\IcoSettings\Interfaces\IcoSettingRepositoryInterface;
use Response;
use User;

class IcoSettingUserController extends UserController
{
    /**
     * Initialize ico_setting controller.
     *
     * @param type IcoSettingRepositoryInterface $ico_setting
     *
     * @return type
     */
    public function __construct(IcoSettingRepositoryInterface $ico_setting)
    {
        $this->model = $ico_setting;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(IcoSettingUserRequest $request)
    {
        $ico_settings = $this->model->all();

        $this->theme->prependTitle(trans('ico_settings::ico_setting.names').' :: ');

        return $this->theme->of('ico_settings::user.ico_setting.index', compact('ico_settings'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(IcoSettingUserRequest $request, $role, $id)
    {
        $ico_setting = $this->model->find($id);

        return $this->theme->of('ico_settings::user.ico_setting.show', compact('ico_setting'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(IcoSettingUserRequest $request)
    {
        $ico_setting = $this->model->findOrNew(0);

        Former::populate($ico_setting);

        return $this->theme->of('ico_settings::user.ico_setting.create', compact('ico_setting'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(IcoSettingUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $ico_setting = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('ico_settings::ico_setting.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(IcoSettingUserRequest $request, $role, $id)
    {
        $ico_setting = $this->model->find($id);

        Former::populate($ico_setting);

        return $this->theme->of('ico_settings::user.ico_setting.edit', compact('ico_setting'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(IcoSettingUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $ico_setting = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('ico_settings::ico_setting.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(IcoSettingUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('ico_settings::ico_setting.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
